"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import identity_endorsement_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DataRoomStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DataRoomStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DataRoomStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Active: _DataRoomStatus.ValueType  # 0
    Stopped: _DataRoomStatus.ValueType  # 1

class DataRoomStatus(_DataRoomStatus, metaclass=_DataRoomStatusEnumTypeWrapper): ...

Active: DataRoomStatus.ValueType  # 0
Stopped: DataRoomStatus.ValueType  # 1
global___DataRoomStatus = DataRoomStatus

@typing_extensions.final
class GcgRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERAUTH_FIELD_NUMBER: builtins.int
    CREATEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGREQUEST_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSREQUEST_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    EXECUTECOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    JOBSTATUSREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSREQUEST_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    EXECUTEDEVELOPMENTCOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATUREREQUEST_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST_FIELD_NUMBER: builtins.int
    CASAUXILIARYSTATEREQUEST_FIELD_NUMBER: builtins.int
    READAUXILIARYSTATEREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEUSEDAIRLOCKQUOTAREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSSIZEREQUEST_FIELD_NUMBER: builtins.int
    ENDORSEMENTREQUEST_FIELD_NUMBER: builtins.int
    @property
    def userAuth(self) -> global___UserAuth: ...
    @property
    def createDataRoomRequest(self) -> global___CreateDataRoomRequest: ...
    @property
    def retrieveDataRoomRequest(self) -> global___RetrieveDataRoomRequest: ...
    @property
    def retrieveCurrentDataRoomConfigurationRequest(self) -> global___RetrieveCurrentDataRoomConfigurationRequest: ...
    @property
    def retrieveDataRoomStatusRequest(self) -> global___RetrieveDataRoomStatusRequest: ...
    @property
    def updateDataRoomStatusRequest(self) -> global___UpdateDataRoomStatusRequest: ...
    @property
    def retrieveAuditLogRequest(self) -> global___RetrieveAuditLogRequest: ...
    @property
    def publishDatasetToDataRoomRequest(self) -> global___PublishDatasetToDataRoomRequest: ...
    @property
    def retrievePublishedDatasetsRequest(self) -> global___RetrievePublishedDatasetsRequest: ...
    @property
    def removePublishedDatasetRequest(self) -> global___RemovePublishedDatasetRequest: ...
    @property
    def executeComputeRequest(self) -> global___ExecuteComputeRequest: ...
    @property
    def jobStatusRequest(self) -> global___JobStatusRequest: ...
    @property
    def getResultsRequest(self) -> global___GetResultsRequest: ...
    @property
    def createConfigurationCommitRequest(self) -> global___CreateConfigurationCommitRequest: ...
    @property
    def retrieveConfigurationCommitRequest(self) -> global___RetrieveConfigurationCommitRequest: ...
    @property
    def executeDevelopmentComputeRequest(self) -> global___ExecuteDevelopmentComputeRequest: ...
    @property
    def generateMergeApprovalSignatureRequest(self) -> global___GenerateMergeApprovalSignatureRequest: ...
    @property
    def mergeConfigurationCommitRequest(self) -> global___MergeConfigurationCommitRequest: ...
    @property
    def retrieveConfigurationCommitApproversRequest(self) -> global___RetrieveConfigurationCommitApproversRequest: ...
    @property
    def casAuxiliaryStateRequest(self) -> global___CasAuxiliaryStateRequest: ...
    @property
    def readAuxiliaryStateRequest(self) -> global___ReadAuxiliaryStateRequest: ...
    @property
    def retrieveUsedAirlockQuotaRequest(self) -> global___RetrieveUsedAirlockQuotaRequest: ...
    @property
    def getResultsSizeRequest(self) -> global___GetResultsSizeRequest: ...
    @property
    def endorsementRequest(self) -> identity_endorsement_pb2.EndorsementRequest: ...
    def __init__(
        self,
        *,
        userAuth: global___UserAuth | None = ...,
        createDataRoomRequest: global___CreateDataRoomRequest | None = ...,
        retrieveDataRoomRequest: global___RetrieveDataRoomRequest | None = ...,
        retrieveCurrentDataRoomConfigurationRequest: global___RetrieveCurrentDataRoomConfigurationRequest | None = ...,
        retrieveDataRoomStatusRequest: global___RetrieveDataRoomStatusRequest | None = ...,
        updateDataRoomStatusRequest: global___UpdateDataRoomStatusRequest | None = ...,
        retrieveAuditLogRequest: global___RetrieveAuditLogRequest | None = ...,
        publishDatasetToDataRoomRequest: global___PublishDatasetToDataRoomRequest | None = ...,
        retrievePublishedDatasetsRequest: global___RetrievePublishedDatasetsRequest | None = ...,
        removePublishedDatasetRequest: global___RemovePublishedDatasetRequest | None = ...,
        executeComputeRequest: global___ExecuteComputeRequest | None = ...,
        jobStatusRequest: global___JobStatusRequest | None = ...,
        getResultsRequest: global___GetResultsRequest | None = ...,
        createConfigurationCommitRequest: global___CreateConfigurationCommitRequest | None = ...,
        retrieveConfigurationCommitRequest: global___RetrieveConfigurationCommitRequest | None = ...,
        executeDevelopmentComputeRequest: global___ExecuteDevelopmentComputeRequest | None = ...,
        generateMergeApprovalSignatureRequest: global___GenerateMergeApprovalSignatureRequest | None = ...,
        mergeConfigurationCommitRequest: global___MergeConfigurationCommitRequest | None = ...,
        retrieveConfigurationCommitApproversRequest: global___RetrieveConfigurationCommitApproversRequest | None = ...,
        casAuxiliaryStateRequest: global___CasAuxiliaryStateRequest | None = ...,
        readAuxiliaryStateRequest: global___ReadAuxiliaryStateRequest | None = ...,
        retrieveUsedAirlockQuotaRequest: global___RetrieveUsedAirlockQuotaRequest | None = ...,
        getResultsSizeRequest: global___GetResultsSizeRequest | None = ...,
        endorsementRequest: identity_endorsement_pb2.EndorsementRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["casAuxiliaryStateRequest", b"casAuxiliaryStateRequest", "createConfigurationCommitRequest", b"createConfigurationCommitRequest", "createDataRoomRequest", b"createDataRoomRequest", "endorsementRequest", b"endorsementRequest", "executeComputeRequest", b"executeComputeRequest", "executeDevelopmentComputeRequest", b"executeDevelopmentComputeRequest", "gcg_request", b"gcg_request", "generateMergeApprovalSignatureRequest", b"generateMergeApprovalSignatureRequest", "getResultsRequest", b"getResultsRequest", "getResultsSizeRequest", b"getResultsSizeRequest", "jobStatusRequest", b"jobStatusRequest", "mergeConfigurationCommitRequest", b"mergeConfigurationCommitRequest", "publishDatasetToDataRoomRequest", b"publishDatasetToDataRoomRequest", "readAuxiliaryStateRequest", b"readAuxiliaryStateRequest", "removePublishedDatasetRequest", b"removePublishedDatasetRequest", "retrieveAuditLogRequest", b"retrieveAuditLogRequest", "retrieveConfigurationCommitApproversRequest", b"retrieveConfigurationCommitApproversRequest", "retrieveConfigurationCommitRequest", b"retrieveConfigurationCommitRequest", "retrieveCurrentDataRoomConfigurationRequest", b"retrieveCurrentDataRoomConfigurationRequest", "retrieveDataRoomRequest", b"retrieveDataRoomRequest", "retrieveDataRoomStatusRequest", b"retrieveDataRoomStatusRequest", "retrievePublishedDatasetsRequest", b"retrievePublishedDatasetsRequest", "retrieveUsedAirlockQuotaRequest", b"retrieveUsedAirlockQuotaRequest", "updateDataRoomStatusRequest", b"updateDataRoomStatusRequest", "userAuth", b"userAuth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["casAuxiliaryStateRequest", b"casAuxiliaryStateRequest", "createConfigurationCommitRequest", b"createConfigurationCommitRequest", "createDataRoomRequest", b"createDataRoomRequest", "endorsementRequest", b"endorsementRequest", "executeComputeRequest", b"executeComputeRequest", "executeDevelopmentComputeRequest", b"executeDevelopmentComputeRequest", "gcg_request", b"gcg_request", "generateMergeApprovalSignatureRequest", b"generateMergeApprovalSignatureRequest", "getResultsRequest", b"getResultsRequest", "getResultsSizeRequest", b"getResultsSizeRequest", "jobStatusRequest", b"jobStatusRequest", "mergeConfigurationCommitRequest", b"mergeConfigurationCommitRequest", "publishDatasetToDataRoomRequest", b"publishDatasetToDataRoomRequest", "readAuxiliaryStateRequest", b"readAuxiliaryStateRequest", "removePublishedDatasetRequest", b"removePublishedDatasetRequest", "retrieveAuditLogRequest", b"retrieveAuditLogRequest", "retrieveConfigurationCommitApproversRequest", b"retrieveConfigurationCommitApproversRequest", "retrieveConfigurationCommitRequest", b"retrieveConfigurationCommitRequest", "retrieveCurrentDataRoomConfigurationRequest", b"retrieveCurrentDataRoomConfigurationRequest", "retrieveDataRoomRequest", b"retrieveDataRoomRequest", "retrieveDataRoomStatusRequest", b"retrieveDataRoomStatusRequest", "retrievePublishedDatasetsRequest", b"retrievePublishedDatasetsRequest", "retrieveUsedAirlockQuotaRequest", b"retrieveUsedAirlockQuotaRequest", "updateDataRoomStatusRequest", b"updateDataRoomStatusRequest", "userAuth", b"userAuth"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["gcg_request", b"gcg_request"]) -> typing_extensions.Literal["createDataRoomRequest", "retrieveDataRoomRequest", "retrieveCurrentDataRoomConfigurationRequest", "retrieveDataRoomStatusRequest", "updateDataRoomStatusRequest", "retrieveAuditLogRequest", "publishDatasetToDataRoomRequest", "retrievePublishedDatasetsRequest", "removePublishedDatasetRequest", "executeComputeRequest", "jobStatusRequest", "getResultsRequest", "createConfigurationCommitRequest", "retrieveConfigurationCommitRequest", "executeDevelopmentComputeRequest", "generateMergeApprovalSignatureRequest", "mergeConfigurationCommitRequest", "retrieveConfigurationCommitApproversRequest", "casAuxiliaryStateRequest", "readAuxiliaryStateRequest", "retrieveUsedAirlockQuotaRequest", "getResultsSizeRequest", "endorsementRequest"] | None: ...

global___GcgRequest = GcgRequest

@typing_extensions.final
class GcgResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_FIELD_NUMBER: builtins.int
    CREATEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGRESPONSE_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSRESPONSE_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    EXECUTECOMPUTERESPONSE_FIELD_NUMBER: builtins.int
    JOBSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSECHUNK_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSEFOOTER_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATURERESPONSE_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE_FIELD_NUMBER: builtins.int
    CASAUXILIARYSTATERESPONSE_FIELD_NUMBER: builtins.int
    READAUXILIARYSTATERESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEUSEDAIRLOCKQUOTARESPONSE_FIELD_NUMBER: builtins.int
    GETRESULTSSIZERESPONSE_FIELD_NUMBER: builtins.int
    ENDORSEMENTRESPONSE_FIELD_NUMBER: builtins.int
    failure: builtins.str
    @property
    def createDataRoomResponse(self) -> global___CreateDataRoomResponse: ...
    @property
    def retrieveDataRoomResponse(self) -> global___RetrieveDataRoomResponse: ...
    @property
    def retrieveCurrentDataRoomConfigurationResponse(self) -> global___RetrieveCurrentDataRoomConfigurationResponse: ...
    @property
    def retrieveDataRoomStatusResponse(self) -> global___RetrieveDataRoomStatusResponse: ...
    @property
    def updateDataRoomStatusResponse(self) -> global___UpdateDataRoomStatusResponse: ...
    @property
    def retrieveAuditLogResponse(self) -> global___RetrieveAuditLogResponse: ...
    @property
    def publishDatasetToDataRoomResponse(self) -> global___PublishDatasetToDataRoomResponse: ...
    @property
    def retrievePublishedDatasetsResponse(self) -> global___RetrievePublishedDatasetsResponse: ...
    @property
    def removePublishedDatasetResponse(self) -> global___RemovePublishedDatasetResponse: ...
    @property
    def executeComputeResponse(self) -> global___ExecuteComputeResponse: ...
    @property
    def jobStatusResponse(self) -> global___JobStatusResponse: ...
    @property
    def getResultsResponseChunk(self) -> global___GetResultsResponseChunk: ...
    @property
    def getResultsResponseFooter(self) -> global___GetResultsResponseFooter: ...
    @property
    def createConfigurationCommitResponse(self) -> global___CreateConfigurationCommitResponse: ...
    @property
    def retrieveConfigurationCommitResponse(self) -> global___RetrieveConfigurationCommitResponse: ...
    @property
    def generateMergeApprovalSignatureResponse(self) -> global___GenerateMergeApprovalSignatureResponse: ...
    @property
    def mergeConfigurationCommitResponse(self) -> global___MergeConfigurationCommitResponse: ...
    @property
    def retrieveConfigurationCommitApproversResponse(self) -> global___RetrieveConfigurationCommitApproversResponse: ...
    @property
    def casAuxiliaryStateResponse(self) -> global___CasAuxiliaryStateResponse: ...
    @property
    def readAuxiliaryStateResponse(self) -> global___ReadAuxiliaryStateResponse: ...
    @property
    def retrieveUsedAirlockQuotaResponse(self) -> global___RetrieveUsedAirlockQuotaResponse: ...
    @property
    def getResultsSizeResponse(self) -> global___GetResultsSizeResponse: ...
    @property
    def endorsementResponse(self) -> identity_endorsement_pb2.EndorsementResponse: ...
    def __init__(
        self,
        *,
        failure: builtins.str = ...,
        createDataRoomResponse: global___CreateDataRoomResponse | None = ...,
        retrieveDataRoomResponse: global___RetrieveDataRoomResponse | None = ...,
        retrieveCurrentDataRoomConfigurationResponse: global___RetrieveCurrentDataRoomConfigurationResponse | None = ...,
        retrieveDataRoomStatusResponse: global___RetrieveDataRoomStatusResponse | None = ...,
        updateDataRoomStatusResponse: global___UpdateDataRoomStatusResponse | None = ...,
        retrieveAuditLogResponse: global___RetrieveAuditLogResponse | None = ...,
        publishDatasetToDataRoomResponse: global___PublishDatasetToDataRoomResponse | None = ...,
        retrievePublishedDatasetsResponse: global___RetrievePublishedDatasetsResponse | None = ...,
        removePublishedDatasetResponse: global___RemovePublishedDatasetResponse | None = ...,
        executeComputeResponse: global___ExecuteComputeResponse | None = ...,
        jobStatusResponse: global___JobStatusResponse | None = ...,
        getResultsResponseChunk: global___GetResultsResponseChunk | None = ...,
        getResultsResponseFooter: global___GetResultsResponseFooter | None = ...,
        createConfigurationCommitResponse: global___CreateConfigurationCommitResponse | None = ...,
        retrieveConfigurationCommitResponse: global___RetrieveConfigurationCommitResponse | None = ...,
        generateMergeApprovalSignatureResponse: global___GenerateMergeApprovalSignatureResponse | None = ...,
        mergeConfigurationCommitResponse: global___MergeConfigurationCommitResponse | None = ...,
        retrieveConfigurationCommitApproversResponse: global___RetrieveConfigurationCommitApproversResponse | None = ...,
        casAuxiliaryStateResponse: global___CasAuxiliaryStateResponse | None = ...,
        readAuxiliaryStateResponse: global___ReadAuxiliaryStateResponse | None = ...,
        retrieveUsedAirlockQuotaResponse: global___RetrieveUsedAirlockQuotaResponse | None = ...,
        getResultsSizeResponse: global___GetResultsSizeResponse | None = ...,
        endorsementResponse: identity_endorsement_pb2.EndorsementResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["casAuxiliaryStateResponse", b"casAuxiliaryStateResponse", "createConfigurationCommitResponse", b"createConfigurationCommitResponse", "createDataRoomResponse", b"createDataRoomResponse", "endorsementResponse", b"endorsementResponse", "executeComputeResponse", b"executeComputeResponse", "failure", b"failure", "gcg_response", b"gcg_response", "generateMergeApprovalSignatureResponse", b"generateMergeApprovalSignatureResponse", "getResultsResponseChunk", b"getResultsResponseChunk", "getResultsResponseFooter", b"getResultsResponseFooter", "getResultsSizeResponse", b"getResultsSizeResponse", "jobStatusResponse", b"jobStatusResponse", "mergeConfigurationCommitResponse", b"mergeConfigurationCommitResponse", "publishDatasetToDataRoomResponse", b"publishDatasetToDataRoomResponse", "readAuxiliaryStateResponse", b"readAuxiliaryStateResponse", "removePublishedDatasetResponse", b"removePublishedDatasetResponse", "retrieveAuditLogResponse", b"retrieveAuditLogResponse", "retrieveConfigurationCommitApproversResponse", b"retrieveConfigurationCommitApproversResponse", "retrieveConfigurationCommitResponse", b"retrieveConfigurationCommitResponse", "retrieveCurrentDataRoomConfigurationResponse", b"retrieveCurrentDataRoomConfigurationResponse", "retrieveDataRoomResponse", b"retrieveDataRoomResponse", "retrieveDataRoomStatusResponse", b"retrieveDataRoomStatusResponse", "retrievePublishedDatasetsResponse", b"retrievePublishedDatasetsResponse", "retrieveUsedAirlockQuotaResponse", b"retrieveUsedAirlockQuotaResponse", "updateDataRoomStatusResponse", b"updateDataRoomStatusResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["casAuxiliaryStateResponse", b"casAuxiliaryStateResponse", "createConfigurationCommitResponse", b"createConfigurationCommitResponse", "createDataRoomResponse", b"createDataRoomResponse", "endorsementResponse", b"endorsementResponse", "executeComputeResponse", b"executeComputeResponse", "failure", b"failure", "gcg_response", b"gcg_response", "generateMergeApprovalSignatureResponse", b"generateMergeApprovalSignatureResponse", "getResultsResponseChunk", b"getResultsResponseChunk", "getResultsResponseFooter", b"getResultsResponseFooter", "getResultsSizeResponse", b"getResultsSizeResponse", "jobStatusResponse", b"jobStatusResponse", "mergeConfigurationCommitResponse", b"mergeConfigurationCommitResponse", "publishDatasetToDataRoomResponse", b"publishDatasetToDataRoomResponse", "readAuxiliaryStateResponse", b"readAuxiliaryStateResponse", "removePublishedDatasetResponse", b"removePublishedDatasetResponse", "retrieveAuditLogResponse", b"retrieveAuditLogResponse", "retrieveConfigurationCommitApproversResponse", b"retrieveConfigurationCommitApproversResponse", "retrieveConfigurationCommitResponse", b"retrieveConfigurationCommitResponse", "retrieveCurrentDataRoomConfigurationResponse", b"retrieveCurrentDataRoomConfigurationResponse", "retrieveDataRoomResponse", b"retrieveDataRoomResponse", "retrieveDataRoomStatusResponse", b"retrieveDataRoomStatusResponse", "retrievePublishedDatasetsResponse", b"retrievePublishedDatasetsResponse", "retrieveUsedAirlockQuotaResponse", b"retrieveUsedAirlockQuotaResponse", "updateDataRoomStatusResponse", b"updateDataRoomStatusResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["gcg_response", b"gcg_response"]) -> typing_extensions.Literal["failure", "createDataRoomResponse", "retrieveDataRoomResponse", "retrieveCurrentDataRoomConfigurationResponse", "retrieveDataRoomStatusResponse", "updateDataRoomStatusResponse", "retrieveAuditLogResponse", "publishDatasetToDataRoomResponse", "retrievePublishedDatasetsResponse", "removePublishedDatasetResponse", "executeComputeResponse", "jobStatusResponse", "getResultsResponseChunk", "getResultsResponseFooter", "createConfigurationCommitResponse", "retrieveConfigurationCommitResponse", "generateMergeApprovalSignatureResponse", "mergeConfigurationCommitResponse", "retrieveConfigurationCommitApproversResponse", "casAuxiliaryStateResponse", "readAuxiliaryStateResponse", "retrieveUsedAirlockQuotaResponse", "getResultsSizeResponse", "endorsementResponse"] | None: ...

global___GcgResponse = GcgResponse

@typing_extensions.final
class UserAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PKI_FIELD_NUMBER: builtins.int
    ENCLAVEENDORSEMENTS_FIELD_NUMBER: builtins.int
    @property
    def pki(self) -> global___Pki: ...
    @property
    def enclaveEndorsements(self) -> identity_endorsement_pb2.EnclaveEndorsements: ...
    def __init__(
        self,
        *,
        pki: global___Pki | None = ...,
        enclaveEndorsements: identity_endorsement_pb2.EnclaveEndorsements | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["enclaveEndorsements", b"enclaveEndorsements", "pki", b"pki"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enclaveEndorsements", b"enclaveEndorsements", "pki", b"pki"]) -> None: ...

global___UserAuth = UserAuth

@typing_extensions.final
class Pki(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTCHAINPEM_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    IDMAC_FIELD_NUMBER: builtins.int
    certChainPem: builtins.bytes
    signature: builtins.bytes
    idMac: builtins.bytes
    def __init__(
        self,
        *,
        certChainPem: builtins.bytes = ...,
        signature: builtins.bytes = ...,
        idMac: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["certChainPem", b"certChainPem", "idMac", b"idMac", "signature", b"signature"]) -> None: ...

global___Pki = Pki

@typing_extensions.final
class CreateDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOM_FIELD_NUMBER: builtins.int
    HIGHLEVELREPRESENTATION_FIELD_NUMBER: builtins.int
    DATAROOMMETADATA_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    highLevelRepresentation: builtins.bytes
    dataRoomMetadata: builtins.bytes
    def __init__(
        self,
        *,
        dataRoom: data_room_pb2.DataRoom | None = ...,
        highLevelRepresentation: builtins.bytes | None = ...,
        dataRoomMetadata: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_dataRoomMetadata", b"_dataRoomMetadata", "_highLevelRepresentation", b"_highLevelRepresentation", "dataRoom", b"dataRoom", "dataRoomMetadata", b"dataRoomMetadata", "highLevelRepresentation", b"highLevelRepresentation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_dataRoomMetadata", b"_dataRoomMetadata", "_highLevelRepresentation", b"_highLevelRepresentation", "dataRoom", b"dataRoom", "dataRoomMetadata", b"dataRoomMetadata", "highLevelRepresentation", b"highLevelRepresentation"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_dataRoomMetadata", b"_dataRoomMetadata"]) -> typing_extensions.Literal["dataRoomMetadata"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation"]) -> typing_extensions.Literal["highLevelRepresentation"] | None: ...

global___CreateDataRoomRequest = CreateDataRoomRequest

@typing_extensions.final
class CreateDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
        dataRoomValidationError: global___DataRoomValidationError | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_data_room_response", b"create_data_room_response", "dataRoomId", b"dataRoomId", "dataRoomValidationError", b"dataRoomValidationError"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_data_room_response", b"create_data_room_response", "dataRoomId", b"dataRoomId", "dataRoomValidationError", b"dataRoomValidationError"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["create_data_room_response", b"create_data_room_response"]) -> typing_extensions.Literal["dataRoomId", "dataRoomValidationError"] | None: ...

global___CreateDataRoomResponse = CreateDataRoomResponse

@typing_extensions.final
class DataRoomValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    PERMISSIONINDEX_FIELD_NUMBER: builtins.int
    COMPUTENODEID_FIELD_NUMBER: builtins.int
    USERPERMISSIONID_FIELD_NUMBER: builtins.int
    ATTESTATIONSPECIFICATIONID_FIELD_NUMBER: builtins.int
    AUTHENTICATIONMETHODID_FIELD_NUMBER: builtins.int
    message: builtins.str
    permissionIndex: builtins.int
    computeNodeId: builtins.str
    userPermissionId: builtins.str
    attestationSpecificationId: builtins.str
    authenticationMethodId: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        permissionIndex: builtins.int | None = ...,
        computeNodeId: builtins.str | None = ...,
        userPermissionId: builtins.str | None = ...,
        attestationSpecificationId: builtins.str | None = ...,
        authenticationMethodId: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_attestationSpecificationId", b"_attestationSpecificationId", "_authenticationMethodId", b"_authenticationMethodId", "_computeNodeId", b"_computeNodeId", "_permissionIndex", b"_permissionIndex", "_userPermissionId", b"_userPermissionId", "attestationSpecificationId", b"attestationSpecificationId", "authenticationMethodId", b"authenticationMethodId", "computeNodeId", b"computeNodeId", "permissionIndex", b"permissionIndex", "userPermissionId", b"userPermissionId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_attestationSpecificationId", b"_attestationSpecificationId", "_authenticationMethodId", b"_authenticationMethodId", "_computeNodeId", b"_computeNodeId", "_permissionIndex", b"_permissionIndex", "_userPermissionId", b"_userPermissionId", "attestationSpecificationId", b"attestationSpecificationId", "authenticationMethodId", b"authenticationMethodId", "computeNodeId", b"computeNodeId", "message", b"message", "permissionIndex", b"permissionIndex", "userPermissionId", b"userPermissionId"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_attestationSpecificationId", b"_attestationSpecificationId"]) -> typing_extensions.Literal["attestationSpecificationId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_authenticationMethodId", b"_authenticationMethodId"]) -> typing_extensions.Literal["authenticationMethodId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_computeNodeId", b"_computeNodeId"]) -> typing_extensions.Literal["computeNodeId"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_permissionIndex", b"_permissionIndex"]) -> typing_extensions.Literal["permissionIndex"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_userPermissionId", b"_userPermissionId"]) -> typing_extensions.Literal["userPermissionId"] | None: ...

global___DataRoomValidationError = DataRoomValidationError

@typing_extensions.final
class PublishDatasetToDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASETHASH_FIELD_NUMBER: builtins.int
    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFID_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    datasetHash: builtins.bytes
    dataRoomId: builtins.bytes
    leafId: builtins.str
    encryptionKey: builtins.bytes
    scope: builtins.bytes
    def __init__(
        self,
        *,
        datasetHash: builtins.bytes = ...,
        dataRoomId: builtins.bytes = ...,
        leafId: builtins.str = ...,
        encryptionKey: builtins.bytes = ...,
        scope: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId", "datasetHash", b"datasetHash", "encryptionKey", b"encryptionKey", "leafId", b"leafId", "scope", b"scope"]) -> None: ...

global___PublishDatasetToDataRoomRequest = PublishDatasetToDataRoomRequest

@typing_extensions.final
class PublishDatasetToDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PublishDatasetToDataRoomResponse = PublishDatasetToDataRoomResponse

@typing_extensions.final
class ExecuteComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TestDatasetsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___TestDataset: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___TestDataset | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATAROOMID_FIELD_NUMBER: builtins.int
    COMPUTENODEIDS_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TESTDATASETS_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    @property
    def computeNodeIds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    isDryRun: builtins.bool
    scope: builtins.bytes
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def testDatasets(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___TestDataset]: ...
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
        computeNodeIds: collections.abc.Iterable[builtins.str] | None = ...,
        isDryRun: builtins.bool = ...,
        scope: builtins.bytes = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        testDatasets: collections.abc.Mapping[builtins.str, global___TestDataset] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeIds", b"computeNodeIds", "dataRoomId", b"dataRoomId", "isDryRun", b"isDryRun", "parameters", b"parameters", "scope", b"scope", "testDatasets", b"testDatasets"]) -> None: ...

global___ExecuteComputeRequest = ExecuteComputeRequest

@typing_extensions.final
class ExecuteDevelopmentComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TestDatasetsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___TestDataset: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___TestDataset | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIGURATIONCOMMITID_FIELD_NUMBER: builtins.int
    COMPUTENODEIDS_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    TESTDATASETS_FIELD_NUMBER: builtins.int
    configurationCommitId: builtins.bytes
    @property
    def computeNodeIds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    isDryRun: builtins.bool
    scope: builtins.bytes
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def testDatasets(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___TestDataset]: ...
    def __init__(
        self,
        *,
        configurationCommitId: builtins.bytes = ...,
        computeNodeIds: collections.abc.Iterable[builtins.str] | None = ...,
        isDryRun: builtins.bool = ...,
        scope: builtins.bytes = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        testDatasets: collections.abc.Mapping[builtins.str, global___TestDataset] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeIds", b"computeNodeIds", "configurationCommitId", b"configurationCommitId", "isDryRun", b"isDryRun", "parameters", b"parameters", "scope", b"scope", "testDatasets", b"testDatasets"]) -> None: ...

global___ExecuteDevelopmentComputeRequest = ExecuteDevelopmentComputeRequest

@typing_extensions.final
class TestDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    MANIFESTHASH_FIELD_NUMBER: builtins.int
    encryptionKey: builtins.bytes
    manifestHash: builtins.bytes
    def __init__(
        self,
        *,
        encryptionKey: builtins.bytes = ...,
        manifestHash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryptionKey", b"encryptionKey", "manifestHash", b"manifestHash"]) -> None: ...

global___TestDataset = TestDataset

@typing_extensions.final
class ExecuteComputeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes
    def __init__(
        self,
        *,
        jobId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobId", b"jobId"]) -> None: ...

global___ExecuteComputeResponse = ExecuteComputeResponse

@typing_extensions.final
class JobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes
    def __init__(
        self,
        *,
        jobId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobId", b"jobId"]) -> None: ...

global___JobStatusRequest = JobStatusRequest

@typing_extensions.final
class JobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPLETECOMPUTENODEIDS_FIELD_NUMBER: builtins.int
    @property
    def completeComputeNodeIds(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        completeComputeNodeIds: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["completeComputeNodeIds", b"completeComputeNodeIds"]) -> None: ...

global___JobStatusResponse = JobStatusResponse

@typing_extensions.final
class GetResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBID_FIELD_NUMBER: builtins.int
    COMPUTENODEID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes
    computeNodeId: builtins.str
    def __init__(
        self,
        *,
        jobId: builtins.bytes = ...,
        computeNodeId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeId", b"computeNodeId", "jobId", b"jobId"]) -> None: ...

global___GetResultsRequest = GetResultsRequest

@typing_extensions.final
class GetResultsSizeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBID_FIELD_NUMBER: builtins.int
    COMPUTENODEID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes
    computeNodeId: builtins.str
    def __init__(
        self,
        *,
        jobId: builtins.bytes = ...,
        computeNodeId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["computeNodeId", b"computeNodeId", "jobId", b"jobId"]) -> None: ...

global___GetResultsSizeRequest = GetResultsSizeRequest

@typing_extensions.final
class GetResultsResponseChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes
    def __init__(
        self,
        *,
        data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___GetResultsResponseChunk = GetResultsResponseChunk

@typing_extensions.final
class GetResultsResponseFooter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetResultsResponseFooter = GetResultsResponseFooter

@typing_extensions.final
class RetrieveDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrieveDataRoomRequest = RetrieveDataRoomRequest

@typing_extensions.final
class RetrieveDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOM_FIELD_NUMBER: builtins.int
    COMMITS_FIELD_NUMBER: builtins.int
    HIGHLEVELREPRESENTATION_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    @property
    def commits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[data_room_pb2.ConfigurationCommit]: ...
    highLevelRepresentation: builtins.bytes
    def __init__(
        self,
        *,
        dataRoom: data_room_pb2.DataRoom | None = ...,
        commits: collections.abc.Iterable[data_room_pb2.ConfigurationCommit] | None = ...,
        highLevelRepresentation: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "dataRoom", b"dataRoom", "highLevelRepresentation", b"highLevelRepresentation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "commits", b"commits", "dataRoom", b"dataRoom", "highLevelRepresentation", b"highLevelRepresentation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation"]) -> typing_extensions.Literal["highLevelRepresentation"] | None: ...

global___RetrieveDataRoomResponse = RetrieveDataRoomResponse

@typing_extensions.final
class RetrieveAuditLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrieveAuditLogRequest = RetrieveAuditLogRequest

@typing_extensions.final
class RetrieveAuditLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_FIELD_NUMBER: builtins.int
    log: builtins.bytes
    def __init__(
        self,
        *,
        log: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["log", b"log"]) -> None: ...

global___RetrieveAuditLogResponse = RetrieveAuditLogResponse

@typing_extensions.final
class RetrieveDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrieveDataRoomStatusRequest = RetrieveDataRoomStatusRequest

@typing_extensions.final
class RetrieveDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: global___DataRoomStatus.ValueType
    def __init__(
        self,
        *,
        status: global___DataRoomStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status"]) -> None: ...

global___RetrieveDataRoomStatusResponse = RetrieveDataRoomStatusResponse

@typing_extensions.final
class UpdateDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    status: global___DataRoomStatus.ValueType
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
        status: global___DataRoomStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId", "status", b"status"]) -> None: ...

global___UpdateDataRoomStatusRequest = UpdateDataRoomStatusRequest

@typing_extensions.final
class UpdateDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateDataRoomStatusResponse = UpdateDataRoomStatusResponse

@typing_extensions.final
class RetrievePublishedDatasetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrievePublishedDatasetsRequest = RetrievePublishedDatasetsRequest

@typing_extensions.final
class PublishedDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEAFID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATASETHASH_FIELD_NUMBER: builtins.int
    leafId: builtins.str
    user: builtins.str
    timestamp: builtins.int
    datasetHash: builtins.bytes
    def __init__(
        self,
        *,
        leafId: builtins.str = ...,
        user: builtins.str = ...,
        timestamp: builtins.int = ...,
        datasetHash: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["datasetHash", b"datasetHash", "leafId", b"leafId", "timestamp", b"timestamp", "user", b"user"]) -> None: ...

global___PublishedDataset = PublishedDataset

@typing_extensions.final
class RetrievePublishedDatasetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISHEDDATASETS_FIELD_NUMBER: builtins.int
    @property
    def publishedDatasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublishedDataset]: ...
    def __init__(
        self,
        *,
        publishedDatasets: collections.abc.Iterable[global___PublishedDataset] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publishedDatasets", b"publishedDatasets"]) -> None: ...

global___RetrievePublishedDatasetsResponse = RetrievePublishedDatasetsResponse

@typing_extensions.final
class RemovePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    leafId: builtins.str
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
        leafId: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId", "leafId", b"leafId"]) -> None: ...

global___RemovePublishedDatasetRequest = RemovePublishedDatasetRequest

@typing_extensions.final
class RemovePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemovePublishedDatasetResponse = RemovePublishedDatasetResponse

@typing_extensions.final
class CreateConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMIT_FIELD_NUMBER: builtins.int
    HIGHLEVELREPRESENTATION_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    highLevelRepresentation: builtins.bytes
    def __init__(
        self,
        *,
        commit: data_room_pb2.ConfigurationCommit | None = ...,
        highLevelRepresentation: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "commit", b"commit", "highLevelRepresentation", b"highLevelRepresentation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "commit", b"commit", "highLevelRepresentation", b"highLevelRepresentation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation"]) -> typing_extensions.Literal["highLevelRepresentation"] | None: ...

global___CreateConfigurationCommitRequest = CreateConfigurationCommitRequest

@typing_extensions.final
class CreateConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes
    def __init__(
        self,
        *,
        commitId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitId", b"commitId"]) -> None: ...

global___CreateConfigurationCommitResponse = CreateConfigurationCommitResponse

@typing_extensions.final
class GenerateMergeApprovalSignatureRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes
    def __init__(
        self,
        *,
        commitId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitId", b"commitId"]) -> None: ...

global___GenerateMergeApprovalSignatureRequest = GenerateMergeApprovalSignatureRequest

@typing_extensions.final
class GenerateMergeApprovalSignatureResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_FIELD_NUMBER: builtins.int
    signature: builtins.bytes
    def __init__(
        self,
        *,
        signature: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["signature", b"signature"]) -> None: ...

global___GenerateMergeApprovalSignatureResponse = GenerateMergeApprovalSignatureResponse

@typing_extensions.final
class MergeConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ApprovalSignaturesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bytes
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bytes = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMMITID_FIELD_NUMBER: builtins.int
    APPROVALSIGNATURES_FIELD_NUMBER: builtins.int
    NEWDATAROOMHIGHLEVELREPRESENTATION_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes
    @property
    def approvalSignatures(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bytes]: ...
    newDataRoomHighLevelRepresentation: builtins.bytes
    def __init__(
        self,
        *,
        commitId: builtins.bytes = ...,
        approvalSignatures: collections.abc.Mapping[builtins.str, builtins.bytes] | None = ...,
        newDataRoomHighLevelRepresentation: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_newDataRoomHighLevelRepresentation", b"_newDataRoomHighLevelRepresentation", "newDataRoomHighLevelRepresentation", b"newDataRoomHighLevelRepresentation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_newDataRoomHighLevelRepresentation", b"_newDataRoomHighLevelRepresentation", "approvalSignatures", b"approvalSignatures", "commitId", b"commitId", "newDataRoomHighLevelRepresentation", b"newDataRoomHighLevelRepresentation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_newDataRoomHighLevelRepresentation", b"_newDataRoomHighLevelRepresentation"]) -> typing_extensions.Literal["newDataRoomHighLevelRepresentation"] | None: ...

global___MergeConfigurationCommitRequest = MergeConfigurationCommitRequest

@typing_extensions.final
class RetrieveCurrentDataRoomConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrieveCurrentDataRoomConfigurationRequest = RetrieveCurrentDataRoomConfigurationRequest

@typing_extensions.final
class RetrieveCurrentDataRoomConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIGURATION_FIELD_NUMBER: builtins.int
    PIN_FIELD_NUMBER: builtins.int
    @property
    def configuration(self) -> data_room_pb2.DataRoomConfiguration: ...
    pin: builtins.bytes
    def __init__(
        self,
        *,
        configuration: data_room_pb2.DataRoomConfiguration | None = ...,
        pin: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "pin", b"pin"]) -> None: ...

global___RetrieveCurrentDataRoomConfigurationResponse = RetrieveCurrentDataRoomConfigurationResponse

@typing_extensions.final
class RetrieveConfigurationCommitApproversRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes
    def __init__(
        self,
        *,
        commitId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitId", b"commitId"]) -> None: ...

global___RetrieveConfigurationCommitApproversRequest = RetrieveConfigurationCommitApproversRequest

@typing_extensions.final
class RetrieveConfigurationCommitApproversResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPROVERS_FIELD_NUMBER: builtins.int
    @property
    def approvers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        approvers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["approvers", b"approvers"]) -> None: ...

global___RetrieveConfigurationCommitApproversResponse = RetrieveConfigurationCommitApproversResponse

@typing_extensions.final
class RetrieveConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes
    def __init__(
        self,
        *,
        commitId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["commitId", b"commitId"]) -> None: ...

global___RetrieveConfigurationCommitRequest = RetrieveConfigurationCommitRequest

@typing_extensions.final
class RetrieveConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMIT_FIELD_NUMBER: builtins.int
    HIGHLEVELREPRESENTATION_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    highLevelRepresentation: builtins.bytes
    def __init__(
        self,
        *,
        commit: data_room_pb2.ConfigurationCommit | None = ...,
        highLevelRepresentation: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "commit", b"commit", "highLevelRepresentation", b"highLevelRepresentation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation", "commit", b"commit", "highLevelRepresentation", b"highLevelRepresentation"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_highLevelRepresentation", b"_highLevelRepresentation"]) -> typing_extensions.Literal["highLevelRepresentation"] | None: ...

global___RetrieveConfigurationCommitResponse = RetrieveConfigurationCommitResponse

@typing_extensions.final
class CasAuxiliaryStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    index: builtins.int
    """The index indicates what the client thinks the state is. The CAS operation will only succeed if the index
    matches what's stored in the enclave. The index is 0 iff the value doesn't exist/was deleted.
    """
    value: builtins.bytes
    """If null it will try to delete value."""
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
        index: builtins.int = ...,
        value: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_value", b"_value", "dataRoomId", b"dataRoomId", "index", b"index", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_value", b"_value"]) -> typing_extensions.Literal["value"] | None: ...

global___CasAuxiliaryStateRequest = CasAuxiliaryStateRequest

@typing_extensions.final
class CasAuxiliaryStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    index: builtins.int
    """The index at the end of the operation, 0 if delete was successful. If success=false, the client should use this
    index and retry the operation, possibly modified based on the returned value.
    Example: User A is racing on two clients X and Y to add numbers 1 and 2 to an initially empty list.
      1. index=0 list=[]: initial state
      2. index=1 list=[1]: User A on client X does CAS(index=0, value=[1])
      3. index=1 list=[1]: User A on client Y does CAS(index=0, value=[2]) => success=false, index=1, value=[1]
      4. index=2 list=[1,2]: User A on client Y retries with CAS(index=1, value=[1,2])
    """
    value: builtins.bytes
    """The value at the end of the operation."""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        index: builtins.int = ...,
        value: builtins.bytes | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_value", b"_value", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_value", b"_value", "index", b"index", "success", b"success", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_value", b"_value"]) -> typing_extensions.Literal["value"] | None: ...

global___CasAuxiliaryStateResponse = CasAuxiliaryStateResponse

@typing_extensions.final
class ReadAuxiliaryStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___ReadAuxiliaryStateRequest = ReadAuxiliaryStateRequest

@typing_extensions.final
class ReadAuxiliaryStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AuxiliaryStateValue]: ...
    def __init__(
        self,
        *,
        values: collections.abc.Iterable[global___AuxiliaryStateValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values", b"values"]) -> None: ...

global___ReadAuxiliaryStateResponse = ReadAuxiliaryStateResponse

@typing_extensions.final
class AuxiliaryStateValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    user: builtins.str
    index: builtins.int
    value: builtins.bytes
    def __init__(
        self,
        *,
        user: builtins.str = ...,
        index: builtins.int = ...,
        value: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["index", b"index", "user", b"user", "value", b"value"]) -> None: ...

global___AuxiliaryStateValue = AuxiliaryStateValue

@typing_extensions.final
class MergeConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MergeConfigurationCommitResponse = MergeConfigurationCommitResponse

@typing_extensions.final
class DriverTaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOOP_FIELD_NUMBER: builtins.int
    STATICCONTENT_FIELD_NUMBER: builtins.int
    @property
    def noop(self) -> global___NoopConfig: ...
    @property
    def staticContent(self) -> global___StaticContentConfig: ...
    def __init__(
        self,
        *,
        noop: global___NoopConfig | None = ...,
        staticContent: global___StaticContentConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["driver_task_config", b"driver_task_config", "noop", b"noop", "staticContent", b"staticContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_task_config", b"driver_task_config", "noop", b"noop", "staticContent", b"staticContent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["driver_task_config", b"driver_task_config"]) -> typing_extensions.Literal["noop", "staticContent"] | None: ...

global___DriverTaskConfig = DriverTaskConfig

@typing_extensions.final
class NoopConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NoopConfig = NoopConfig

@typing_extensions.final
class StaticContentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content"]) -> None: ...

global___StaticContentConfig = StaticContentConfig

@typing_extensions.final
class RetrieveUsedAirlockQuotaRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes
    def __init__(
        self,
        *,
        dataRoomId: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataRoomId", b"dataRoomId"]) -> None: ...

global___RetrieveUsedAirlockQuotaRequest = RetrieveUsedAirlockQuotaRequest

@typing_extensions.final
class RetrieveUsedAirlockQuotaResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIRLOCKQUOTAS_FIELD_NUMBER: builtins.int
    @property
    def airlockQuotas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AirlockQuotaInfo]: ...
    def __init__(
        self,
        *,
        airlockQuotas: collections.abc.Iterable[global___AirlockQuotaInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["airlockQuotas", b"airlockQuotas"]) -> None: ...

global___RetrieveUsedAirlockQuotaResponse = RetrieveUsedAirlockQuotaResponse

@typing_extensions.final
class AirlockQuotaInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIRLOCKNODEID_FIELD_NUMBER: builtins.int
    QUOTABYTES_FIELD_NUMBER: builtins.int
    USEDQUOTABYTES_FIELD_NUMBER: builtins.int
    airlockNodeId: builtins.str
    quotaBytes: builtins.int
    usedQuotaBytes: builtins.int
    def __init__(
        self,
        *,
        airlockNodeId: builtins.str = ...,
        quotaBytes: builtins.int = ...,
        usedQuotaBytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["airlockNodeId", b"airlockNodeId", "quotaBytes", b"quotaBytes", "usedQuotaBytes", b"usedQuotaBytes"]) -> None: ...

global___AirlockQuotaInfo = AirlockQuotaInfo

@typing_extensions.final
class GetResultsSizeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZEBYTES_FIELD_NUMBER: builtins.int
    sizeBytes: builtins.int
    def __init__(
        self,
        *,
        sizeBytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sizeBytes", b"sizeBytes"]) -> None: ...

global___GetResultsSizeResponse = GetResultsSizeResponse
