# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure_blob_storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61zure_blob_storage.proto\x12\x12\x61zure_blob_storage\"\x0c\n\nImportRole\":\n\nExportRole\x12,\n\x05input\x18\x01 \x01(\x0b\x32\x1d.azure_blob_storage.SinkInput\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"L\n\x07ZipFile\x12\x34\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1e.azure_blob_storage.SingleFileH\x00\x42\x0b\n\tselection\"\x8d\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12*\n\x03raw\x18\x03 \x01(\x0b\x32\x1b.azure_blob_storage.RawFileH\x00\x12*\n\x03zip\x18\x04 \x01(\x0b\x32\x1b.azure_blob_storage.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xb8\x01\n#AzureBlobStorageWorkerConfiguration\x12\x1d\n\x15\x63redentialsDependency\x18\x01 \x01(\t\x12\x34\n\nimportRole\x18\x02 \x01(\x0b\x32\x1e.azure_blob_storage.ImportRoleH\x00\x12\x34\n\nexportRole\x18\x03 \x01(\x0b\x32\x1e.azure_blob_storage.ExportRoleH\x00\x42\x06\n\x04roleb\x06proto3')



_IMPORTROLE = DESCRIPTOR.message_types_by_name['ImportRole']
_EXPORTROLE = DESCRIPTOR.message_types_by_name['ExportRole']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_AZUREBLOBSTORAGEWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['AzureBlobStorageWorkerConfiguration']
ImportRole = _reflection.GeneratedProtocolMessageType('ImportRole', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTROLE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ImportRole)
  })
_sym_db.RegisterMessage(ImportRole)

ExportRole = _reflection.GeneratedProtocolMessageType('ExportRole', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTROLE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ExportRole)
  })
_sym_db.RegisterMessage(ExportRole)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

AzureBlobStorageWorkerConfiguration = _reflection.GeneratedProtocolMessageType('AzureBlobStorageWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _AZUREBLOBSTORAGEWORKERCONFIGURATION,
  '__module__' : 'azure_blob_storage_pb2'
  # @@protoc_insertion_point(class_scope:azure_blob_storage.AzureBlobStorageWorkerConfiguration)
  })
_sym_db.RegisterMessage(AzureBlobStorageWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IMPORTROLE._serialized_start=48
  _IMPORTROLE._serialized_end=60
  _EXPORTROLE._serialized_start=62
  _EXPORTROLE._serialized_end=120
  _SINGLEFILE._serialized_start=122
  _SINGLEFILE._serialized_end=148
  _RAWFILE._serialized_start=150
  _RAWFILE._serialized_end=159
  _ZIPFILE._serialized_start=161
  _ZIPFILE._serialized_end=237
  _SINKINPUT._serialized_start=240
  _SINKINPUT._serialized_end=381
  _AZUREBLOBSTORAGEWORKERCONFIGURATION._serialized_start=384
  _AZUREBLOBSTORAGEWORKERCONFIGURATION._serialized_end=568
# @@protoc_insertion_point(module_scope)
