# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: salesforce.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10salesforce.proto\x12\nsalesforce\"\x06\n\x04\x43ore\"\x10\n\x0eMarketingCloud\"s\n\nImportRole\x12 \n\x04\x63ore\x18\x01 \x01(\x0b\x32\x10.salesforce.CoreH\x00\x12\x34\n\x0emarketingCloud\x18\x02 \x01(\x0b\x32\x1a.salesforce.MarketingCloudH\x00\x42\r\n\x0bproductType\"2\n\nExportRole\x12$\n\x05input\x18\x01 \x01(\x0b\x32\x15.salesforce.SinkInput\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"D\n\x07ZipFile\x12,\n\nsingleFile\x18\x01 \x01(\x0b\x32\x16.salesforce.SingleFileH\x00\x42\x0b\n\tselection\"}\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x03raw\x18\x03 \x01(\x0b\x32\x13.salesforce.RawFileH\x00\x12\"\n\x03zip\x18\x04 \x01(\x0b\x32\x13.salesforce.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xc6\x01\n\x1dSalesforceWorkerConfiguration\x12\x1d\n\x15\x63redentialsDependency\x18\x01 \x01(\t\x12,\n\nimportRole\x18\x02 \x01(\x0b\x32\x16.salesforce.ImportRoleH\x00\x12,\n\nexportRole\x18\x03 \x01(\x0b\x32\x16.salesforce.ExportRoleH\x00\x12\x11\n\tdomainUrl\x18\x04 \x01(\t\x12\x0f\n\x07\x61piName\x18\x05 \x01(\tB\x06\n\x04roleb\x06proto3')



_CORE = DESCRIPTOR.message_types_by_name['Core']
_MARKETINGCLOUD = DESCRIPTOR.message_types_by_name['MarketingCloud']
_IMPORTROLE = DESCRIPTOR.message_types_by_name['ImportRole']
_EXPORTROLE = DESCRIPTOR.message_types_by_name['ExportRole']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_SALESFORCEWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['SalesforceWorkerConfiguration']
Core = _reflection.GeneratedProtocolMessageType('Core', (_message.Message,), {
  'DESCRIPTOR' : _CORE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.Core)
  })
_sym_db.RegisterMessage(Core)

MarketingCloud = _reflection.GeneratedProtocolMessageType('MarketingCloud', (_message.Message,), {
  'DESCRIPTOR' : _MARKETINGCLOUD,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.MarketingCloud)
  })
_sym_db.RegisterMessage(MarketingCloud)

ImportRole = _reflection.GeneratedProtocolMessageType('ImportRole', (_message.Message,), {
  'DESCRIPTOR' : _IMPORTROLE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ImportRole)
  })
_sym_db.RegisterMessage(ImportRole)

ExportRole = _reflection.GeneratedProtocolMessageType('ExportRole', (_message.Message,), {
  'DESCRIPTOR' : _EXPORTROLE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ExportRole)
  })
_sym_db.RegisterMessage(ExportRole)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

SalesforceWorkerConfiguration = _reflection.GeneratedProtocolMessageType('SalesforceWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _SALESFORCEWORKERCONFIGURATION,
  '__module__' : 'salesforce_pb2'
  # @@protoc_insertion_point(class_scope:salesforce.SalesforceWorkerConfiguration)
  })
_sym_db.RegisterMessage(SalesforceWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CORE._serialized_start=32
  _CORE._serialized_end=38
  _MARKETINGCLOUD._serialized_start=40
  _MARKETINGCLOUD._serialized_end=56
  _IMPORTROLE._serialized_start=58
  _IMPORTROLE._serialized_end=173
  _EXPORTROLE._serialized_start=175
  _EXPORTROLE._serialized_end=225
  _SINGLEFILE._serialized_start=227
  _SINGLEFILE._serialized_end=253
  _RAWFILE._serialized_start=255
  _RAWFILE._serialized_end=264
  _ZIPFILE._serialized_start=266
  _ZIPFILE._serialized_end=334
  _SINKINPUT._serialized_start=336
  _SINKINPUT._serialized_end=461
  _SALESFORCEWORKERCONFIGURATION._serialized_start=464
  _SALESFORCEWORKERCONFIGURATION._serialized_end=662
# @@protoc_insertion_point(module_scope)
