# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import identity_endorsement_pb2 as identity__endorsement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgcg.proto\x12\x03gcg\x1a\x0f\x64\x61ta_room.proto\x1a\x1aidentity_endorsement.proto\"\x82\x0e\n\nGcgRequest\x12\x1f\n\x08userAuth\x18\x01 \x01(\x0b\x32\r.gcg.UserAuth\x12;\n\x15\x63reateDataRoomRequest\x18\x02 \x01(\x0b\x32\x1a.gcg.CreateDataRoomRequestH\x00\x12?\n\x17retrieveDataRoomRequest\x18\x03 \x01(\x0b\x32\x1c.gcg.RetrieveDataRoomRequestH\x00\x12g\n+retrieveCurrentDataRoomConfigurationRequest\x18\x04 \x01(\x0b\x32\x30.gcg.RetrieveCurrentDataRoomConfigurationRequestH\x00\x12K\n\x1dretrieveDataRoomStatusRequest\x18\x05 \x01(\x0b\x32\".gcg.RetrieveDataRoomStatusRequestH\x00\x12G\n\x1bupdateDataRoomStatusRequest\x18\x06 \x01(\x0b\x32 .gcg.UpdateDataRoomStatusRequestH\x00\x12?\n\x17retrieveAuditLogRequest\x18\x07 \x01(\x0b\x32\x1c.gcg.RetrieveAuditLogRequestH\x00\x12O\n\x1fpublishDatasetToDataRoomRequest\x18\x08 \x01(\x0b\x32$.gcg.PublishDatasetToDataRoomRequestH\x00\x12Q\n retrievePublishedDatasetsRequest\x18\t \x01(\x0b\x32%.gcg.RetrievePublishedDatasetsRequestH\x00\x12K\n\x1dremovePublishedDatasetRequest\x18\n \x01(\x0b\x32\".gcg.RemovePublishedDatasetRequestH\x00\x12;\n\x15\x65xecuteComputeRequest\x18\x0b \x01(\x0b\x32\x1a.gcg.ExecuteComputeRequestH\x00\x12\x31\n\x10jobStatusRequest\x18\x0c \x01(\x0b\x32\x15.gcg.JobStatusRequestH\x00\x12\x33\n\x11getResultsRequest\x18\r \x01(\x0b\x32\x16.gcg.GetResultsRequestH\x00\x12Q\n createConfigurationCommitRequest\x18\x0e \x01(\x0b\x32%.gcg.CreateConfigurationCommitRequestH\x00\x12U\n\"retrieveConfigurationCommitRequest\x18\x0f \x01(\x0b\x32\'.gcg.RetrieveConfigurationCommitRequestH\x00\x12Q\n executeDevelopmentComputeRequest\x18\x10 \x01(\x0b\x32%.gcg.ExecuteDevelopmentComputeRequestH\x00\x12[\n%generateMergeApprovalSignatureRequest\x18\x11 \x01(\x0b\x32*.gcg.GenerateMergeApprovalSignatureRequestH\x00\x12O\n\x1fmergeConfigurationCommitRequest\x18\x12 \x01(\x0b\x32$.gcg.MergeConfigurationCommitRequestH\x00\x12g\n+retrieveConfigurationCommitApproversRequest\x18\x13 \x01(\x0b\x32\x30.gcg.RetrieveConfigurationCommitApproversRequestH\x00\x12\x41\n\x18\x63\x61sAuxiliaryStateRequest\x18\x14 \x01(\x0b\x32\x1d.gcg.CasAuxiliaryStateRequestH\x00\x12\x43\n\x19readAuxiliaryStateRequest\x18\x15 \x01(\x0b\x32\x1e.gcg.ReadAuxiliaryStateRequestH\x00\x12O\n\x1fretrieveUsedAirlockQuotaRequest\x18\x16 \x01(\x0b\x32$.gcg.RetrieveUsedAirlockQuotaRequestH\x00\x12;\n\x15getResultsSizeRequest\x18\x17 \x01(\x0b\x32\x1a.gcg.GetResultsSizeRequestH\x00\x12\x46\n\x12\x65ndorsementRequest\x18\x65 \x01(\x0b\x32(.identity_endorsement.EndorsementRequestH\x00\x42\r\n\x0bgcg_request\"\x9c\x0e\n\x0bGcgResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12=\n\x16\x63reateDataRoomResponse\x18\x02 \x01(\x0b\x32\x1b.gcg.CreateDataRoomResponseH\x00\x12\x41\n\x18retrieveDataRoomResponse\x18\x03 \x01(\x0b\x32\x1d.gcg.RetrieveDataRoomResponseH\x00\x12i\n,retrieveCurrentDataRoomConfigurationResponse\x18\x04 \x01(\x0b\x32\x31.gcg.RetrieveCurrentDataRoomConfigurationResponseH\x00\x12M\n\x1eretrieveDataRoomStatusResponse\x18\x05 \x01(\x0b\x32#.gcg.RetrieveDataRoomStatusResponseH\x00\x12I\n\x1cupdateDataRoomStatusResponse\x18\x06 \x01(\x0b\x32!.gcg.UpdateDataRoomStatusResponseH\x00\x12\x41\n\x18retrieveAuditLogResponse\x18\x07 \x01(\x0b\x32\x1d.gcg.RetrieveAuditLogResponseH\x00\x12Q\n publishDatasetToDataRoomResponse\x18\x08 \x01(\x0b\x32%.gcg.PublishDatasetToDataRoomResponseH\x00\x12S\n!retrievePublishedDatasetsResponse\x18\t \x01(\x0b\x32&.gcg.RetrievePublishedDatasetsResponseH\x00\x12M\n\x1eremovePublishedDatasetResponse\x18\n \x01(\x0b\x32#.gcg.RemovePublishedDatasetResponseH\x00\x12=\n\x16\x65xecuteComputeResponse\x18\x0b \x01(\x0b\x32\x1b.gcg.ExecuteComputeResponseH\x00\x12\x33\n\x11jobStatusResponse\x18\x0c \x01(\x0b\x32\x16.gcg.JobStatusResponseH\x00\x12?\n\x17getResultsResponseChunk\x18\r \x01(\x0b\x32\x1c.gcg.GetResultsResponseChunkH\x00\x12\x41\n\x18getResultsResponseFooter\x18\x0e \x01(\x0b\x32\x1d.gcg.GetResultsResponseFooterH\x00\x12S\n!createConfigurationCommitResponse\x18\x0f \x01(\x0b\x32&.gcg.CreateConfigurationCommitResponseH\x00\x12W\n#retrieveConfigurationCommitResponse\x18\x10 \x01(\x0b\x32(.gcg.RetrieveConfigurationCommitResponseH\x00\x12]\n&generateMergeApprovalSignatureResponse\x18\x11 \x01(\x0b\x32+.gcg.GenerateMergeApprovalSignatureResponseH\x00\x12Q\n mergeConfigurationCommitResponse\x18\x12 \x01(\x0b\x32%.gcg.MergeConfigurationCommitResponseH\x00\x12i\n,retrieveConfigurationCommitApproversResponse\x18\x13 \x01(\x0b\x32\x31.gcg.RetrieveConfigurationCommitApproversResponseH\x00\x12\x43\n\x19\x63\x61sAuxiliaryStateResponse\x18\x14 \x01(\x0b\x32\x1e.gcg.CasAuxiliaryStateResponseH\x00\x12\x45\n\x1areadAuxiliaryStateResponse\x18\x15 \x01(\x0b\x32\x1f.gcg.ReadAuxiliaryStateResponseH\x00\x12Q\n retrieveUsedAirlockQuotaResponse\x18\x16 \x01(\x0b\x32%.gcg.RetrieveUsedAirlockQuotaResponseH\x00\x12=\n\x16getResultsSizeResponse\x18\x17 \x01(\x0b\x32\x1b.gcg.GetResultsSizeResponseH\x00\x12H\n\x13\x65ndorsementResponse\x18\x65 \x01(\x0b\x32).identity_endorsement.EndorsementResponseH\x00\x42\x0e\n\x0cgcg_response\"i\n\x08UserAuth\x12\x15\n\x03pki\x18\x01 \x01(\x0b\x32\x08.gcg.Pki\x12\x46\n\x13\x65nclaveEndorsements\x18\x02 \x01(\x0b\x32).identity_endorsement.EnclaveEndorsements\"=\n\x03Pki\x12\x14\n\x0c\x63\x65rtChainPem\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12\r\n\x05idMac\x18\x03 \x01(\x0c\"\xb4\x01\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x12\x1d\n\x10\x64\x61taRoomMetadata\x18\x03 \x01(\x0cH\x01\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentationB\x13\n\x11_dataRoomMetadata\"\x8c\x01\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12?\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1c.gcg.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xc6\x02\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1c\n\x0fpermissionIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1a\n\rcomputeNodeId\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10userPermissionId\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\'\n\x1a\x61ttestationSpecificationId\x18\x05 \x01(\tH\x03\x88\x01\x01\x12#\n\x16\x61uthenticationMethodId\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x12\n\x10_permissionIndexB\x10\n\x0e_computeNodeIdB\x13\n\x11_userPermissionIdB\x1d\n\x1b_attestationSpecificationIdB\x19\n\x17_authenticationMethodId\"\x80\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x13\n\x0b\x64\x61tasetHash\x18\x01 \x01(\x0c\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x0e\n\x06leafId\x18\x03 \x01(\t\x12\x15\n\rencryptionKey\x18\x04 \x01(\x0c\x12\r\n\x05scope\x18\x05 \x01(\x0c\"\"\n PublishDatasetToDataRoomResponse\"\xe2\x02\n\x15\x45xecuteComputeRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12>\n\nparameters\x18\x05 \x03(\x0b\x32*.gcg.ExecuteComputeRequest.ParametersEntry\x12\x42\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32,.gcg.ExecuteComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\"\x8e\x03\n ExecuteDevelopmentComputeRequest\x12\x1d\n\x15\x63onfigurationCommitId\x18\x01 \x01(\x0c\x12\x16\n\x0e\x63omputeNodeIds\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\x12I\n\nparameters\x18\x05 \x03(\x0b\x32\x35.gcg.ExecuteDevelopmentComputeRequest.ParametersEntry\x12M\n\x0ctestDatasets\x18\x06 \x03(\x0b\x32\x37.gcg.ExecuteDevelopmentComputeRequest.TestDatasetsEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x45\n\x11TestDatasetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.gcg.TestDataset:\x02\x38\x01\":\n\x0bTestDataset\x12\x15\n\rencryptionKey\x18\x01 \x01(\x0c\x12\x14\n\x0cmanifestHash\x18\x02 \x01(\x0c\"\'\n\x16\x45xecuteComputeResponse\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"!\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"3\n\x11JobStatusResponse\x12\x1e\n\x16\x63ompleteComputeNodeIds\x18\x01 \x03(\t\"9\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"=\n\x15GetResultsSizeRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x15\n\rcomputeNodeId\x18\x02 \x01(\t\"\'\n\x17GetResultsResponseChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1a\n\x18GetResultsResponseFooter\"-\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\xb4\x01\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12/\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"-\n\x17RetrieveAuditLogRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"\'\n\x18RetrieveAuditLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"3\n\x1dRetrieveDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"E\n\x1eRetrieveDataRoomStatusResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"V\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12#\n\x06status\x18\x02 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"6\n RetrievePublishedDatasetsRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"X\n\x10PublishedDataset\x12\x0e\n\x06leafId\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x61tasetHash\x18\x04 \x01(\x0c\"U\n!RetrievePublishedDatasetsResponse\x12\x30\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x15.gcg.PublishedDataset\"C\n\x1dRemovePublishedDatasetRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x0e\n\x06leafId\x18\x02 \x01(\t\" \n\x1eRemovePublishedDatasetResponse\"\x94\x01\n CreateConfigurationCommitRequest\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"5\n!CreateConfigurationCommitResponse\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"9\n%GenerateMergeApprovalSignatureRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\";\n&GenerateMergeApprovalSignatureResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"\xa0\x02\n\x1fMergeConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\x12X\n\x12\x61pprovalSignatures\x18\x02 \x03(\x0b\x32<.gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry\x12/\n\"newDataRoomHighLevelRepresentation\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x1a\x39\n\x17\x41pprovalSignaturesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x42%\n#_newDataRoomHighLevelRepresentation\"A\n+RetrieveCurrentDataRoomConfigurationRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"t\n,RetrieveCurrentDataRoomConfigurationResponse\x12\x37\n\rconfiguration\x18\x01 \x01(\x0b\x32 .data_room.DataRoomConfiguration\x12\x0b\n\x03pin\x18\x02 \x01(\x0c\"?\n+RetrieveConfigurationCommitApproversRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"A\n,RetrieveConfigurationCommitApproversResponse\x12\x11\n\tapprovers\x18\x01 \x03(\t\"6\n\"RetrieveConfigurationCommitRequest\x12\x10\n\x08\x63ommitId\x18\x01 \x01(\x0c\"\x97\x01\n#RetrieveConfigurationCommitResponse\x12.\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x1e.data_room.ConfigurationCommit\x12$\n\x17highLevelRepresentation\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x1a\n\x18_highLevelRepresentation\"[\n\x18\x43\x61sAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"Y\n\x19\x43\x61sAuxiliaryStateResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05index\x18\x02 \x01(\x04\x12\x12\n\x05value\x18\x03 \x01(\x0cH\x00\x88\x01\x01\x42\x08\n\x06_value\"/\n\x19ReadAuxiliaryStateRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"F\n\x1aReadAuxiliaryStateResponse\x12(\n\x06values\x18\x02 \x03(\x0b\x32\x18.gcg.AuxiliaryStateValue\"A\n\x13\x41uxiliaryStateValue\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\r\n\x05index\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x01(\x0c\"\"\n MergeConfigurationCommitResponse\"|\n\x10\x44riverTaskConfig\x12\x1f\n\x04noop\x18\x01 \x01(\x0b\x32\x0f.gcg.NoopConfigH\x00\x12\x31\n\rstaticContent\x18\x02 \x01(\x0b\x32\x18.gcg.StaticContentConfigH\x00\x42\x14\n\x12\x64river_task_config\"\x0c\n\nNoopConfig\"&\n\x13StaticContentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"5\n\x1fRetrieveUsedAirlockQuotaRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\"P\n RetrieveUsedAirlockQuotaResponse\x12,\n\rairlockQuotas\x18\x01 \x03(\x0b\x32\x15.gcg.AirlockQuotaInfo\"U\n\x10\x41irlockQuotaInfo\x12\x15\n\rairlockNodeId\x18\x01 \x01(\t\x12\x12\n\nquotaBytes\x18\x02 \x01(\x04\x12\x16\n\x0eusedQuotaBytes\x18\x03 \x01(\x04\"+\n\x16GetResultsSizeResponse\x12\x11\n\tsizeBytes\x18\x01 \x01(\x04*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_DATAROOMSTATUS = DESCRIPTOR.enum_types_by_name['DataRoomStatus']
DataRoomStatus = enum_type_wrapper.EnumTypeWrapper(_DATAROOMSTATUS)
Active = 0
Stopped = 1


_GCGREQUEST = DESCRIPTOR.message_types_by_name['GcgRequest']
_GCGRESPONSE = DESCRIPTOR.message_types_by_name['GcgResponse']
_USERAUTH = DESCRIPTOR.message_types_by_name['UserAuth']
_PKI = DESCRIPTOR.message_types_by_name['Pki']
_CREATEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['CreateDataRoomRequest']
_CREATEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataRoomResponse']
_DATAROOMVALIDATIONERROR = DESCRIPTOR.message_types_by_name['DataRoomValidationError']
_PUBLISHDATASETTODATAROOMREQUEST = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomRequest']
_PUBLISHDATASETTODATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomResponse']
_EXECUTECOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteComputeRequest']
_EXECUTECOMPUTEREQUEST_PARAMETERSENTRY = _EXECUTECOMPUTEREQUEST.nested_types_by_name['ParametersEntry']
_EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY = _EXECUTECOMPUTEREQUEST.nested_types_by_name['TestDatasetsEntry']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteDevelopmentComputeRequest']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY = _EXECUTEDEVELOPMENTCOMPUTEREQUEST.nested_types_by_name['ParametersEntry']
_EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY = _EXECUTEDEVELOPMENTCOMPUTEREQUEST.nested_types_by_name['TestDatasetsEntry']
_TESTDATASET = DESCRIPTOR.message_types_by_name['TestDataset']
_EXECUTECOMPUTERESPONSE = DESCRIPTOR.message_types_by_name['ExecuteComputeResponse']
_JOBSTATUSREQUEST = DESCRIPTOR.message_types_by_name['JobStatusRequest']
_JOBSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['JobStatusResponse']
_GETRESULTSREQUEST = DESCRIPTOR.message_types_by_name['GetResultsRequest']
_GETRESULTSSIZEREQUEST = DESCRIPTOR.message_types_by_name['GetResultsSizeRequest']
_GETRESULTSRESPONSECHUNK = DESCRIPTOR.message_types_by_name['GetResultsResponseChunk']
_GETRESULTSRESPONSEFOOTER = DESCRIPTOR.message_types_by_name['GetResultsResponseFooter']
_RETRIEVEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomRequest']
_RETRIEVEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomResponse']
_RETRIEVEAUDITLOGREQUEST = DESCRIPTOR.message_types_by_name['RetrieveAuditLogRequest']
_RETRIEVEAUDITLOGRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveAuditLogResponse']
_RETRIEVEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusRequest']
_RETRIEVEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusResponse']
_UPDATEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusRequest']
_UPDATEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusResponse']
_RETRIEVEPUBLISHEDDATASETSREQUEST = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsRequest']
_PUBLISHEDDATASET = DESCRIPTOR.message_types_by_name['PublishedDataset']
_RETRIEVEPUBLISHEDDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsResponse']
_REMOVEPUBLISHEDDATASETREQUEST = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetRequest']
_REMOVEPUBLISHEDDATASETRESPONSE = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetResponse']
_CREATECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitRequest']
_CREATECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['CreateConfigurationCommitResponse']
_GENERATEMERGEAPPROVALSIGNATUREREQUEST = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureRequest']
_GENERATEMERGEAPPROVALSIGNATURERESPONSE = DESCRIPTOR.message_types_by_name['GenerateMergeApprovalSignatureResponse']
_MERGECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitRequest']
_MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY = _MERGECONFIGURATIONCOMMITREQUEST.nested_types_by_name['ApprovalSignaturesEntry']
_RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['RetrieveCurrentDataRoomConfigurationRequest']
_RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveCurrentDataRoomConfigurationResponse']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversRequest']
_RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitApproversResponse']
_RETRIEVECONFIGURATIONCOMMITREQUEST = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitRequest']
_RETRIEVECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveConfigurationCommitResponse']
_CASAUXILIARYSTATEREQUEST = DESCRIPTOR.message_types_by_name['CasAuxiliaryStateRequest']
_CASAUXILIARYSTATERESPONSE = DESCRIPTOR.message_types_by_name['CasAuxiliaryStateResponse']
_READAUXILIARYSTATEREQUEST = DESCRIPTOR.message_types_by_name['ReadAuxiliaryStateRequest']
_READAUXILIARYSTATERESPONSE = DESCRIPTOR.message_types_by_name['ReadAuxiliaryStateResponse']
_AUXILIARYSTATEVALUE = DESCRIPTOR.message_types_by_name['AuxiliaryStateValue']
_MERGECONFIGURATIONCOMMITRESPONSE = DESCRIPTOR.message_types_by_name['MergeConfigurationCommitResponse']
_DRIVERTASKCONFIG = DESCRIPTOR.message_types_by_name['DriverTaskConfig']
_NOOPCONFIG = DESCRIPTOR.message_types_by_name['NoopConfig']
_STATICCONTENTCONFIG = DESCRIPTOR.message_types_by_name['StaticContentConfig']
_RETRIEVEUSEDAIRLOCKQUOTAREQUEST = DESCRIPTOR.message_types_by_name['RetrieveUsedAirlockQuotaRequest']
_RETRIEVEUSEDAIRLOCKQUOTARESPONSE = DESCRIPTOR.message_types_by_name['RetrieveUsedAirlockQuotaResponse']
_AIRLOCKQUOTAINFO = DESCRIPTOR.message_types_by_name['AirlockQuotaInfo']
_GETRESULTSSIZERESPONSE = DESCRIPTOR.message_types_by_name['GetResultsSizeResponse']
GcgRequest = _reflection.GeneratedProtocolMessageType('GcgRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgRequest)
  })
_sym_db.RegisterMessage(GcgRequest)

GcgResponse = _reflection.GeneratedProtocolMessageType('GcgResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgResponse)
  })
_sym_db.RegisterMessage(GcgResponse)

UserAuth = _reflection.GeneratedProtocolMessageType('UserAuth', (_message.Message,), {
  'DESCRIPTOR' : _USERAUTH,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UserAuth)
  })
_sym_db.RegisterMessage(UserAuth)

Pki = _reflection.GeneratedProtocolMessageType('Pki', (_message.Message,), {
  'DESCRIPTOR' : _PKI,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.Pki)
  })
_sym_db.RegisterMessage(Pki)

CreateDataRoomRequest = _reflection.GeneratedProtocolMessageType('CreateDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomRequest)
  })
_sym_db.RegisterMessage(CreateDataRoomRequest)

CreateDataRoomResponse = _reflection.GeneratedProtocolMessageType('CreateDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomResponse)
  })
_sym_db.RegisterMessage(CreateDataRoomResponse)

DataRoomValidationError = _reflection.GeneratedProtocolMessageType('DataRoomValidationError', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMVALIDATIONERROR,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DataRoomValidationError)
  })
_sym_db.RegisterMessage(DataRoomValidationError)

PublishDatasetToDataRoomRequest = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomRequest)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomRequest)

PublishDatasetToDataRoomResponse = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomResponse)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomResponse)

ExecuteComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteComputeRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest.ParametersEntry)
    })
  ,

  'TestDatasetsEntry' : _reflection.GeneratedProtocolMessageType('TestDatasetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest.TestDatasetsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteComputeRequest)
_sym_db.RegisterMessage(ExecuteComputeRequest.ParametersEntry)
_sym_db.RegisterMessage(ExecuteComputeRequest.TestDatasetsEntry)

ExecuteDevelopmentComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteDevelopmentComputeRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest.ParametersEntry)
    })
  ,

  'TestDatasetsEntry' : _reflection.GeneratedProtocolMessageType('TestDatasetsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest.TestDatasetsEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEDEVELOPMENTCOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteDevelopmentComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest)
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest.ParametersEntry)
_sym_db.RegisterMessage(ExecuteDevelopmentComputeRequest.TestDatasetsEntry)

TestDataset = _reflection.GeneratedProtocolMessageType('TestDataset', (_message.Message,), {
  'DESCRIPTOR' : _TESTDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.TestDataset)
  })
_sym_db.RegisterMessage(TestDataset)

ExecuteComputeResponse = _reflection.GeneratedProtocolMessageType('ExecuteComputeResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeResponse)
  })
_sym_db.RegisterMessage(ExecuteComputeResponse)

JobStatusRequest = _reflection.GeneratedProtocolMessageType('JobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusRequest)
  })
_sym_db.RegisterMessage(JobStatusRequest)

JobStatusResponse = _reflection.GeneratedProtocolMessageType('JobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusResponse)
  })
_sym_db.RegisterMessage(JobStatusResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsSizeRequest = _reflection.GeneratedProtocolMessageType('GetResultsSizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSSIZEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsSizeRequest)
  })
_sym_db.RegisterMessage(GetResultsSizeRequest)

GetResultsResponseChunk = _reflection.GeneratedProtocolMessageType('GetResultsResponseChunk', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSECHUNK,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseChunk)
  })
_sym_db.RegisterMessage(GetResultsResponseChunk)

GetResultsResponseFooter = _reflection.GeneratedProtocolMessageType('GetResultsResponseFooter', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSEFOOTER,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseFooter)
  })
_sym_db.RegisterMessage(GetResultsResponseFooter)

RetrieveDataRoomRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomRequest)

RetrieveDataRoomResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomResponse)

RetrieveAuditLogRequest = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogRequest)
  })
_sym_db.RegisterMessage(RetrieveAuditLogRequest)

RetrieveAuditLogResponse = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogResponse)
  })
_sym_db.RegisterMessage(RetrieveAuditLogResponse)

RetrieveDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusRequest)

RetrieveDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusResponse)

UpdateDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusRequest)

UpdateDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusResponse)

RetrievePublishedDatasetsRequest = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsRequest)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsRequest)

PublishedDataset = _reflection.GeneratedProtocolMessageType('PublishedDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishedDataset)
  })
_sym_db.RegisterMessage(PublishedDataset)

RetrievePublishedDatasetsResponse = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsResponse)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsResponse)

RemovePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetRequest)

RemovePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetResponse)

CreateConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitRequest)

CreateConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('CreateConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(CreateConfigurationCommitResponse)

GenerateMergeApprovalSignatureRequest = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATUREREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureRequest)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureRequest)

GenerateMergeApprovalSignatureResponse = _reflection.GeneratedProtocolMessageType('GenerateMergeApprovalSignatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEMERGEAPPROVALSIGNATURERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GenerateMergeApprovalSignatureResponse)
  })
_sym_db.RegisterMessage(GenerateMergeApprovalSignatureResponse)

MergeConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitRequest', (_message.Message,), {

  'ApprovalSignaturesEntry' : _reflection.GeneratedProtocolMessageType('ApprovalSignaturesEntry', (_message.Message,), {
    'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY,
    '__module__' : 'gcg_pb2'
    # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest.ApprovalSignaturesEntry)
    })
  ,
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitRequest)
_sym_db.RegisterMessage(MergeConfigurationCommitRequest.ApprovalSignaturesEntry)

RetrieveCurrentDataRoomConfigurationRequest = _reflection.GeneratedProtocolMessageType('RetrieveCurrentDataRoomConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveCurrentDataRoomConfigurationRequest)
  })
_sym_db.RegisterMessage(RetrieveCurrentDataRoomConfigurationRequest)

RetrieveCurrentDataRoomConfigurationResponse = _reflection.GeneratedProtocolMessageType('RetrieveCurrentDataRoomConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveCurrentDataRoomConfigurationResponse)
  })
_sym_db.RegisterMessage(RetrieveCurrentDataRoomConfigurationResponse)

RetrieveConfigurationCommitApproversRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversRequest)

RetrieveConfigurationCommitApproversResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitApproversResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitApproversResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitApproversResponse)

RetrieveConfigurationCommitRequest = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitRequest)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitRequest)

RetrieveConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('RetrieveConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(RetrieveConfigurationCommitResponse)

CasAuxiliaryStateRequest = _reflection.GeneratedProtocolMessageType('CasAuxiliaryStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CASAUXILIARYSTATEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CasAuxiliaryStateRequest)
  })
_sym_db.RegisterMessage(CasAuxiliaryStateRequest)

CasAuxiliaryStateResponse = _reflection.GeneratedProtocolMessageType('CasAuxiliaryStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CASAUXILIARYSTATERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CasAuxiliaryStateResponse)
  })
_sym_db.RegisterMessage(CasAuxiliaryStateResponse)

ReadAuxiliaryStateRequest = _reflection.GeneratedProtocolMessageType('ReadAuxiliaryStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _READAUXILIARYSTATEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ReadAuxiliaryStateRequest)
  })
_sym_db.RegisterMessage(ReadAuxiliaryStateRequest)

ReadAuxiliaryStateResponse = _reflection.GeneratedProtocolMessageType('ReadAuxiliaryStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _READAUXILIARYSTATERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ReadAuxiliaryStateResponse)
  })
_sym_db.RegisterMessage(ReadAuxiliaryStateResponse)

AuxiliaryStateValue = _reflection.GeneratedProtocolMessageType('AuxiliaryStateValue', (_message.Message,), {
  'DESCRIPTOR' : _AUXILIARYSTATEVALUE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.AuxiliaryStateValue)
  })
_sym_db.RegisterMessage(AuxiliaryStateValue)

MergeConfigurationCommitResponse = _reflection.GeneratedProtocolMessageType('MergeConfigurationCommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _MERGECONFIGURATIONCOMMITRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.MergeConfigurationCommitResponse)
  })
_sym_db.RegisterMessage(MergeConfigurationCommitResponse)

DriverTaskConfig = _reflection.GeneratedProtocolMessageType('DriverTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERTASKCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DriverTaskConfig)
  })
_sym_db.RegisterMessage(DriverTaskConfig)

NoopConfig = _reflection.GeneratedProtocolMessageType('NoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOOPCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.NoopConfig)
  })
_sym_db.RegisterMessage(NoopConfig)

StaticContentConfig = _reflection.GeneratedProtocolMessageType('StaticContentConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICCONTENTCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.StaticContentConfig)
  })
_sym_db.RegisterMessage(StaticContentConfig)

RetrieveUsedAirlockQuotaRequest = _reflection.GeneratedProtocolMessageType('RetrieveUsedAirlockQuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEUSEDAIRLOCKQUOTAREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveUsedAirlockQuotaRequest)
  })
_sym_db.RegisterMessage(RetrieveUsedAirlockQuotaRequest)

RetrieveUsedAirlockQuotaResponse = _reflection.GeneratedProtocolMessageType('RetrieveUsedAirlockQuotaResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEUSEDAIRLOCKQUOTARESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveUsedAirlockQuotaResponse)
  })
_sym_db.RegisterMessage(RetrieveUsedAirlockQuotaResponse)

AirlockQuotaInfo = _reflection.GeneratedProtocolMessageType('AirlockQuotaInfo', (_message.Message,), {
  'DESCRIPTOR' : _AIRLOCKQUOTAINFO,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.AirlockQuotaInfo)
  })
_sym_db.RegisterMessage(AirlockQuotaInfo)

GetResultsSizeResponse = _reflection.GeneratedProtocolMessageType('GetResultsSizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSSIZERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsSizeResponse)
  })
_sym_db.RegisterMessage(GetResultsSizeResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._options = None
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._options = None
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_options = b'8\001'
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._options = None
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_options = b'8\001'
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._options = None
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_options = b'8\001'
  _DATAROOMSTATUS._serialized_start=8712
  _DATAROOMSTATUS._serialized_end=8753
  _GCGREQUEST._serialized_start=64
  _GCGREQUEST._serialized_end=1858
  _GCGRESPONSE._serialized_start=1861
  _GCGRESPONSE._serialized_end=3681
  _USERAUTH._serialized_start=3683
  _USERAUTH._serialized_end=3788
  _PKI._serialized_start=3790
  _PKI._serialized_end=3851
  _CREATEDATAROOMREQUEST._serialized_start=3854
  _CREATEDATAROOMREQUEST._serialized_end=4034
  _CREATEDATAROOMRESPONSE._serialized_start=4037
  _CREATEDATAROOMRESPONSE._serialized_end=4177
  _DATAROOMVALIDATIONERROR._serialized_start=4180
  _DATAROOMVALIDATIONERROR._serialized_end=4506
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_start=4509
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_end=4637
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_start=4639
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_end=4673
  _EXECUTECOMPUTEREQUEST._serialized_start=4676
  _EXECUTECOMPUTEREQUEST._serialized_end=5030
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_start=4910
  _EXECUTECOMPUTEREQUEST_PARAMETERSENTRY._serialized_end=4959
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_start=4961
  _EXECUTECOMPUTEREQUEST_TESTDATASETSENTRY._serialized_end=5030
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_start=5033
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST._serialized_end=5431
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_start=4910
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_PARAMETERSENTRY._serialized_end=4959
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_start=4961
  _EXECUTEDEVELOPMENTCOMPUTEREQUEST_TESTDATASETSENTRY._serialized_end=5030
  _TESTDATASET._serialized_start=5433
  _TESTDATASET._serialized_end=5491
  _EXECUTECOMPUTERESPONSE._serialized_start=5493
  _EXECUTECOMPUTERESPONSE._serialized_end=5532
  _JOBSTATUSREQUEST._serialized_start=5534
  _JOBSTATUSREQUEST._serialized_end=5567
  _JOBSTATUSRESPONSE._serialized_start=5569
  _JOBSTATUSRESPONSE._serialized_end=5620
  _GETRESULTSREQUEST._serialized_start=5622
  _GETRESULTSREQUEST._serialized_end=5679
  _GETRESULTSSIZEREQUEST._serialized_start=5681
  _GETRESULTSSIZEREQUEST._serialized_end=5742
  _GETRESULTSRESPONSECHUNK._serialized_start=5744
  _GETRESULTSRESPONSECHUNK._serialized_end=5783
  _GETRESULTSRESPONSEFOOTER._serialized_start=5785
  _GETRESULTSRESPONSEFOOTER._serialized_end=5811
  _RETRIEVEDATAROOMREQUEST._serialized_start=5813
  _RETRIEVEDATAROOMREQUEST._serialized_end=5858
  _RETRIEVEDATAROOMRESPONSE._serialized_start=5861
  _RETRIEVEDATAROOMRESPONSE._serialized_end=6041
  _RETRIEVEAUDITLOGREQUEST._serialized_start=6043
  _RETRIEVEAUDITLOGREQUEST._serialized_end=6088
  _RETRIEVEAUDITLOGRESPONSE._serialized_start=6090
  _RETRIEVEAUDITLOGRESPONSE._serialized_end=6129
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_start=6131
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_end=6182
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_start=6184
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_end=6253
  _UPDATEDATAROOMSTATUSREQUEST._serialized_start=6255
  _UPDATEDATAROOMSTATUSREQUEST._serialized_end=6341
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_start=6343
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_end=6373
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_start=6375
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_end=6429
  _PUBLISHEDDATASET._serialized_start=6431
  _PUBLISHEDDATASET._serialized_end=6519
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_start=6521
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_end=6606
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_start=6608
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_end=6675
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_start=6677
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_end=6709
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_start=6712
  _CREATECONFIGURATIONCOMMITREQUEST._serialized_end=6860
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_start=6862
  _CREATECONFIGURATIONCOMMITRESPONSE._serialized_end=6915
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_start=6917
  _GENERATEMERGEAPPROVALSIGNATUREREQUEST._serialized_end=6974
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_start=6976
  _GENERATEMERGEAPPROVALSIGNATURERESPONSE._serialized_end=7035
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_start=7038
  _MERGECONFIGURATIONCOMMITREQUEST._serialized_end=7326
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_start=7230
  _MERGECONFIGURATIONCOMMITREQUEST_APPROVALSIGNATURESENTRY._serialized_end=7287
  _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST._serialized_start=7328
  _RETRIEVECURRENTDATAROOMCONFIGURATIONREQUEST._serialized_end=7393
  _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE._serialized_start=7395
  _RETRIEVECURRENTDATAROOMCONFIGURATIONRESPONSE._serialized_end=7511
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_start=7513
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST._serialized_end=7576
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_start=7578
  _RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE._serialized_end=7643
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_start=7645
  _RETRIEVECONFIGURATIONCOMMITREQUEST._serialized_end=7699
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_start=7702
  _RETRIEVECONFIGURATIONCOMMITRESPONSE._serialized_end=7853
  _CASAUXILIARYSTATEREQUEST._serialized_start=7855
  _CASAUXILIARYSTATEREQUEST._serialized_end=7946
  _CASAUXILIARYSTATERESPONSE._serialized_start=7948
  _CASAUXILIARYSTATERESPONSE._serialized_end=8037
  _READAUXILIARYSTATEREQUEST._serialized_start=8039
  _READAUXILIARYSTATEREQUEST._serialized_end=8086
  _READAUXILIARYSTATERESPONSE._serialized_start=8088
  _READAUXILIARYSTATERESPONSE._serialized_end=8158
  _AUXILIARYSTATEVALUE._serialized_start=8160
  _AUXILIARYSTATEVALUE._serialized_end=8225
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_start=8227
  _MERGECONFIGURATIONCOMMITRESPONSE._serialized_end=8261
  _DRIVERTASKCONFIG._serialized_start=8263
  _DRIVERTASKCONFIG._serialized_end=8387
  _NOOPCONFIG._serialized_start=8389
  _NOOPCONFIG._serialized_end=8401
  _STATICCONTENTCONFIG._serialized_start=8403
  _STATICCONTENTCONFIG._serialized_end=8441
  _RETRIEVEUSEDAIRLOCKQUOTAREQUEST._serialized_start=8443
  _RETRIEVEUSEDAIRLOCKQUOTAREQUEST._serialized_end=8496
  _RETRIEVEUSEDAIRLOCKQUOTARESPONSE._serialized_start=8498
  _RETRIEVEUSEDAIRLOCKQUOTARESPONSE._serialized_end=8578
  _AIRLOCKQUOTAINFO._serialized_start=8580
  _AIRLOCKQUOTAINFO._serialized_end=8665
  _GETRESULTSSIZERESPONSE._serialized_start=8667
  _GETRESULTSSIZERESPONSE._serialized_end=8710
# @@protoc_insertion_point(module_scope)
