# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: compute_container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63ompute_container.proto\x12\x11\x63ompute_container\"a\n\x1c\x43ontainerWorkerConfiguration\x12\x30\n\x06static\x18\x01 \x01(\x0b\x32\x1e.compute_container.StaticImageH\x00\x42\x0f\n\rconfiguration\"\xbf\x03\n\x0bStaticImage\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\x12\x32\n\x0bmountPoints\x18\x02 \x03(\x0b\x32\x1d.compute_container.MountPoint\x12\x12\n\noutputPath\x18\x03 \x01(\t\x12#\n\x1bincludeContainerLogsOnError\x18\x04 \x01(\x08\x12%\n\x1dincludeContainerLogsOnSuccess\x18\x05 \x01(\x08\x12\'\n\x1aminimumContainerMemorySize\x18\x06 \x01(\x04H\x00\x88\x01\x01\x12\x36\n)extraChunkCacheSizeToAvailableMemoryRatio\x18\x07 \x01(\x02H\x01\x88\x01\x01\x12\x46\n\x12proxyConfiguration\x18\x08 \x01(\x0b\x32%.compute_container.ProxyConfigurationH\x02\x88\x01\x01\x42\x1d\n\x1b_minimumContainerMemorySizeB,\n*_extraChunkCacheSizeToAvailableMemoryRatioB\x15\n\x13_proxyConfiguration\"\xb7\x01\n\x12ProxyConfiguration\x12?\n\x07liberal\x18\x01 \x01(\x0b\x32,.compute_container.ProxyConfigurationLiberalH\x00\x12O\n\x0f\x64omainAllowlist\x18\x02 \x01(\x0b\x32\x34.compute_container.ProxyConfigurationDomainAllowlistH\x00\x42\x0f\n\rconfiguration\"\x1b\n\x19ProxyConfigurationLiberal\"3\n!ProxyConfigurationDomainAllowlist\x12\x0e\n\x06\x64omain\x18\x01 \x03(\t\".\n\nMountPoint\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\ndependency\x18\x02 \x01(\tb\x06proto3')



_CONTAINERWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['ContainerWorkerConfiguration']
_STATICIMAGE = DESCRIPTOR.message_types_by_name['StaticImage']
_PROXYCONFIGURATION = DESCRIPTOR.message_types_by_name['ProxyConfiguration']
_PROXYCONFIGURATIONLIBERAL = DESCRIPTOR.message_types_by_name['ProxyConfigurationLiberal']
_PROXYCONFIGURATIONDOMAINALLOWLIST = DESCRIPTOR.message_types_by_name['ProxyConfigurationDomainAllowlist']
_MOUNTPOINT = DESCRIPTOR.message_types_by_name['MountPoint']
ContainerWorkerConfiguration = _reflection.GeneratedProtocolMessageType('ContainerWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERWORKERCONFIGURATION,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ContainerWorkerConfiguration)
  })
_sym_db.RegisterMessage(ContainerWorkerConfiguration)

StaticImage = _reflection.GeneratedProtocolMessageType('StaticImage', (_message.Message,), {
  'DESCRIPTOR' : _STATICIMAGE,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.StaticImage)
  })
_sym_db.RegisterMessage(StaticImage)

ProxyConfiguration = _reflection.GeneratedProtocolMessageType('ProxyConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATION,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfiguration)
  })
_sym_db.RegisterMessage(ProxyConfiguration)

ProxyConfigurationLiberal = _reflection.GeneratedProtocolMessageType('ProxyConfigurationLiberal', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATIONLIBERAL,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfigurationLiberal)
  })
_sym_db.RegisterMessage(ProxyConfigurationLiberal)

ProxyConfigurationDomainAllowlist = _reflection.GeneratedProtocolMessageType('ProxyConfigurationDomainAllowlist', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCONFIGURATIONDOMAINALLOWLIST,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.ProxyConfigurationDomainAllowlist)
  })
_sym_db.RegisterMessage(ProxyConfigurationDomainAllowlist)

MountPoint = _reflection.GeneratedProtocolMessageType('MountPoint', (_message.Message,), {
  'DESCRIPTOR' : _MOUNTPOINT,
  '__module__' : 'compute_container_pb2'
  # @@protoc_insertion_point(class_scope:compute_container.MountPoint)
  })
_sym_db.RegisterMessage(MountPoint)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONTAINERWORKERCONFIGURATION._serialized_start=46
  _CONTAINERWORKERCONFIGURATION._serialized_end=143
  _STATICIMAGE._serialized_start=146
  _STATICIMAGE._serialized_end=593
  _PROXYCONFIGURATION._serialized_start=596
  _PROXYCONFIGURATION._serialized_end=779
  _PROXYCONFIGURATIONLIBERAL._serialized_start=781
  _PROXYCONFIGURATIONLIBERAL._serialized_end=808
  _PROXYCONFIGURATIONDOMAINALLOWLIST._serialized_start=810
  _PROXYCONFIGURATIONDOMAINALLOWLIST._serialized_end=861
  _MOUNTPOINT._serialized_start=863
  _MOUNTPOINT._serialized_end=909
# @@protoc_insertion_point(module_scope)
