# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google_ad_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17google_ad_manager.proto\x12\x11google_ad_manager\"\x1a\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\"\t\n\x07RawFile\"K\n\x07ZipFile\x12\x33\n\nsingleFile\x18\x01 \x01(\x0b\x32\x1d.google_ad_manager.SingleFileH\x00\x42\x0b\n\tselection\"\x8b\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x03raw\x18\x03 \x01(\x0b\x32\x1a.google_ad_manager.RawFileH\x00\x12)\n\x03zip\x18\x04 \x01(\x0b\x32\x1a.google_ad_manager.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xd5\x01\n\"GoogleAdManagerWorkerConfiguration\x12+\n\x05input\x18\x01 \x01(\x0b\x32\x1c.google_ad_manager.SinkInput\x12\x1d\n\x15\x63redentialsDependency\x18\x02 \x01(\t\x12\x16\n\x0eidentifierKind\x18\x03 \x01(\t\x12\x0e\n\x06listId\x18\x04 \x01(\t\x12\x17\n\x0finputHasHeaders\x18\x05 \x01(\x08\x12\x0e\n\x06\x62ucket\x18\x06 \x01(\t\x12\x12\n\nobjectName\x18\x07 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_ad_manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SINGLEFILE']._serialized_start=46
  _globals['_SINGLEFILE']._serialized_end=72
  _globals['_RAWFILE']._serialized_start=74
  _globals['_RAWFILE']._serialized_end=83
  _globals['_ZIPFILE']._serialized_start=85
  _globals['_ZIPFILE']._serialized_end=160
  _globals['_SINKINPUT']._serialized_start=163
  _globals['_SINKINPUT']._serialized_end=302
  _globals['_GOOGLEADMANAGERWORKERCONFIGURATION']._serialized_start=305
  _globals['_GOOGLEADMANAGERWORKERCONFIGURATION']._serialized_end=518
# @@protoc_insertion_point(module_scope)
