# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dataset_sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x61taset_sink.proto\x12\x0c\x64\x61taset_sink\"\t\n\x07RawFile\"\n\n\x08\x41llFiles\">\n\nSingleFile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\x08renameAs\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_renameAs\"8\n\rFileSelection\x12\'\n\x05names\x18\x01 \x03(\x0b\x32\x18.dataset_sink.SingleFile\"k\n\x07ZipFile\x12%\n\x03\x61ll\x18\x01 \x01(\x0b\x32\x16.dataset_sink.AllFilesH\x00\x12,\n\x05\x66iles\x18\x02 \x01(\x0b\x32\x1b.dataset_sink.FileSelectionH\x00\x42\x0b\n\tselection\"\x81\x01\n\tSinkInput\x12\x12\n\ndependency\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x03raw\x18\x03 \x01(\x0b\x32\x15.dataset_sink.RawFileH\x00\x12$\n\x03zip\x18\x04 \x01(\x0b\x32\x15.dataset_sink.ZipFileH\x00\x42\x06\n\x04\x66ile\"\xb5\x01\n\x1e\x44\x61tasetSinkWorkerConfiguration\x12\'\n\x06inputs\x18\x01 \x03(\x0b\x32\x17.dataset_sink.SinkInput\x12\x1f\n\x17\x65ncryptionKeyDependency\x18\x02 \x01(\t\x12\x1c\n\x0f\x64\x61tasetImportId\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x17\n\x0fisKeyHexEncoded\x18\x04 \x01(\x08\x42\x12\n\x10_datasetImportIdb\x06proto3')



_RAWFILE = DESCRIPTOR.message_types_by_name['RawFile']
_ALLFILES = DESCRIPTOR.message_types_by_name['AllFiles']
_SINGLEFILE = DESCRIPTOR.message_types_by_name['SingleFile']
_FILESELECTION = DESCRIPTOR.message_types_by_name['FileSelection']
_ZIPFILE = DESCRIPTOR.message_types_by_name['ZipFile']
_SINKINPUT = DESCRIPTOR.message_types_by_name['SinkInput']
_DATASETSINKWORKERCONFIGURATION = DESCRIPTOR.message_types_by_name['DatasetSinkWorkerConfiguration']
RawFile = _reflection.GeneratedProtocolMessageType('RawFile', (_message.Message,), {
  'DESCRIPTOR' : _RAWFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.RawFile)
  })
_sym_db.RegisterMessage(RawFile)

AllFiles = _reflection.GeneratedProtocolMessageType('AllFiles', (_message.Message,), {
  'DESCRIPTOR' : _ALLFILES,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.AllFiles)
  })
_sym_db.RegisterMessage(AllFiles)

SingleFile = _reflection.GeneratedProtocolMessageType('SingleFile', (_message.Message,), {
  'DESCRIPTOR' : _SINGLEFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.SingleFile)
  })
_sym_db.RegisterMessage(SingleFile)

FileSelection = _reflection.GeneratedProtocolMessageType('FileSelection', (_message.Message,), {
  'DESCRIPTOR' : _FILESELECTION,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.FileSelection)
  })
_sym_db.RegisterMessage(FileSelection)

ZipFile = _reflection.GeneratedProtocolMessageType('ZipFile', (_message.Message,), {
  'DESCRIPTOR' : _ZIPFILE,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.ZipFile)
  })
_sym_db.RegisterMessage(ZipFile)

SinkInput = _reflection.GeneratedProtocolMessageType('SinkInput', (_message.Message,), {
  'DESCRIPTOR' : _SINKINPUT,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.SinkInput)
  })
_sym_db.RegisterMessage(SinkInput)

DatasetSinkWorkerConfiguration = _reflection.GeneratedProtocolMessageType('DatasetSinkWorkerConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _DATASETSINKWORKERCONFIGURATION,
  '__module__' : 'dataset_sink_pb2'
  # @@protoc_insertion_point(class_scope:dataset_sink.DatasetSinkWorkerConfiguration)
  })
_sym_db.RegisterMessage(DatasetSinkWorkerConfiguration)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RAWFILE._serialized_start=36
  _RAWFILE._serialized_end=45
  _ALLFILES._serialized_start=47
  _ALLFILES._serialized_end=57
  _SINGLEFILE._serialized_start=59
  _SINGLEFILE._serialized_end=121
  _FILESELECTION._serialized_start=123
  _FILESELECTION._serialized_end=179
  _ZIPFILE._serialized_start=181
  _ZIPFILE._serialized_end=288
  _SINKINPUT._serialized_start=291
  _SINKINPUT._serialized_end=420
  _DATASETSINKWORKERCONFIGURATION._serialized_start=423
  _DATASETSINKWORKERCONFIGURATION._serialized_end=604
# @@protoc_insertion_point(module_scope)
